@@ -284,8 +284,7 @@ shinyServer(function(input, output, session) {
                                            raw = chosenRaw(),
                                            k = chosenNumberOfPowers(),
                                            predictors = NULL,
-                                           terms = chosenNumberOfTerms(),
-                                           plot = FALSE)
+                                           terms = chosenNumberOfTerms())
     }
     else{
       currentBestModel <- cNORM::bestModel(data = preparedData(),
@@ -293,8 +292,7 @@ shinyServer(function(input, output, session) {
                                            k = chosenNumberOfPowers(),
                                            predictors = NULL,
                                            R2 = chosenCoeffOfDet(),
-                                           terms = 0,
-                                           plot = FALSE)
+                                           terms = 0)
     }
 
 
@@ -352,7 +350,7 @@ shinyServer(function(input, output, session) {
     cNORM::plotRaw(preparedData(), bestModel(), group = chosenGrouping(), raw = chosenRaw())
   })
 
-  normScorePlot <- eventReactive(c(input$grouping, input$differences), {
+  normScorePlot <- eventReactive(c(input$grouping, input$differences, input$normScoreButton), {
     type <- 0
     if(input$differences)
       type <- 1
@@ -378,7 +376,7 @@ shinyServer(function(input, output, session) {
   })
 
 
-  rawScorePlot <- eventReactive(c(input$grouping1, input$differences1), {
+  rawScorePlot <- eventReactive(c(input$grouping1, input$differences1, input$rawScoreButton), {
     type <- 0
     if(input$differences1)
       type <- 1
